'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzyme = require('enzyme');

var _index = require('../index');

var _index2 = _interopRequireDefault(_index);

var _immutable = require('immutable');

var _chai = require('chai');

var _draftJs = require('draft-js');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('UndoButton', function () {
  var onChange = function onChange() {
    return undefined;
  };
  var editorState = void 0;

  beforeEach(function () {
    editorState = _draftJs.EditorState.createEmpty();
  });

  it('applies the className based on the theme property `hashtag`', function () {
    var theme = (0, _immutable.Map)({ undo: 'custom-class-name' });
    var result = (0, _enzyme.shallow)(_react2.default.createElement(_index2.default, {
      editorState: editorState,
      onChange: onChange,
      theme: theme,
      children: 'undo'
    }));
    (0, _chai.expect)(result).to.have.prop('className', 'custom-class-name');
  });

  it('renders the passed in children', function () {
    var result = (0, _enzyme.shallow)(_react2.default.createElement(_index2.default, {
      editorState: editorState,
      onChange: onChange,
      children: 'undo'
    }));
    (0, _chai.expect)(result).to.have.prop('children', 'undo');
  });

  it('applies a custom className as well as the theme', function () {
    var theme = (0, _immutable.Map)({ undo: 'custom-class-name' });
    var result = (0, _enzyme.shallow)(_react2.default.createElement(_index2.default, {
      editorState: editorState,
      onChange: onChange,
      theme: theme,
      className: 'hashtag',
      children: 'undo'
    }));
    (0, _chai.expect)(result).to.have.prop('className').to.contain('hashtag');
    (0, _chai.expect)(result).to.have.prop('className').to.contain('custom-class-name');
  });

  // TODO test: button is disabled in case the getUndoStack is empty
  // TODO test: button is not disabled in case the getUndoStack is not empty
  // TODO test: onClick on the button triggers an update with a undo
});